"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PositionRecord = void 0;
const uuid_1 = require("uuid");
const db_1 = require("../utils/db");
const errors_1 = require("../utils/errors");
class PositionRecord {
    constructor(obj) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l;
        if (!obj.userId) {
            throw new errors_1.ValidationError('Nie podano ID użytkownika do którego przypisać pozycję.');
        }
        if (!obj.direction) {
            throw new errors_1.ValidationError('Nie zdefiniowano kierunku handlu');
        }
        if (obj.market.length === 0 || obj.market.length > 10) {
            throw new errors_1.ValidationError('WALOR nie możebyć pusty ani zawierać więcej niż 10 znaków.');
        }
        if (obj.descriptionBefore && obj.descriptionBefore.length > 1500) {
            throw new errors_1.ValidationError('Opis nie może zawierać więcej niż 1500 znaków.');
        }
        if (obj.descriptionAfter && obj.descriptionAfter.length > 1500) {
            throw new errors_1.ValidationError('Opis nie może zawierać więcej niż 1500 znaków.');
        }
        if (!obj.userId)
            throw new errors_1.ValidationError('ID użytkownika jest wymagane.');
        this.id = (_a = obj.id) !== null && _a !== void 0 ? _a : (0, uuid_1.v4)();
        this.userId = obj.userId;
        this.market = obj.market;
        this.direction = obj.direction;
        this.result = (_b = obj.result) !== null && _b !== void 0 ? _b : '';
        this.date = obj.date;
        this.flag = (_c = obj.flag) !== null && _c !== void 0 ? _c : 0;
        this.imgUrlBefore = (_d = obj.imgUrlBefore) !== null && _d !== void 0 ? _d : null;
        this.imgUrlAfter = (_e = obj.imgUrlAfter) !== null && _e !== void 0 ? _e : null;
        this.descriptionBefore = (_f = obj.descriptionBefore) !== null && _f !== void 0 ? _f : null;
        this.descriptionAfter = (_g = obj.descriptionAfter) !== null && _g !== void 0 ? _g : null;
        this.entryPrice = (_h = obj.entryPrice) !== null && _h !== void 0 ? _h : null;
        this.slValue = (_j = obj.slValue) !== null && _j !== void 0 ? _j : null;
        this.closePrice = (_k = obj.closePrice) !== null && _k !== void 0 ? _k : null;
        this.rr = (_l = obj.rr) !== null && _l !== void 0 ? _l : null;
    }
    static getAll(userId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute("SELECT * FROM `positions` WHERE `userId` = :userId", {
                userId,
            }));
            return results.length === 0 ? null : results.map(result => new PositionRecord(result));
        });
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute("SELECT * FROM `positions` WHERE `id` = :id", {
                id,
            }));
            if (results.length === 0) {
                throw new errors_1.ValidationError('Pozycja o podanym ID nie istnieje.');
            }
            else
                return new PositionRecord(results[0]);
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("INSERT INTO `positions` (`id`, `market`, `direction`, `date`, `userId`, `entryPrice`, `slValue`) VALUES(:id, :market, :direction, :date, :userId, :entryPrice, :slValue)", {
                id: this.id,
                market: this.market,
                direction: this.direction,
                date: this.date,
                userId: this.userId,
                entryPrice: this.entryPrice,
                slValue: this.slValue
            });
            console.log('▶.....Position has been successfully inserted. ✔');
        });
    }
    update(data) {
        return __awaiter(this, void 0, void 0, function* () {
            const updated = Object.assign(Object.assign({}, this), data);
            yield db_1.pool.execute("UPDATE `positions` SET `market` = :market, `direction` = :direction, `date` = :date, `result` = :result, `flag` = :flag, `descriptionBefore` = :descriptionBefore, `descriptionAfter` = :descriptionAfter, `entryPrice` = :entryPrice, `slValue` = :slValue, `closePrice` = :closePrice, `rr` = :rr WHERE `id` = :id", {
                id: this.id,
                market: updated.market,
                direction: updated.direction,
                result: updated.result,
                date: updated.date,
                flag: updated.flag,
                descriptionBefore: updated.descriptionBefore,
                descriptionAfter: updated.descriptionAfter,
                entryPrice: updated.entryPrice,
                slValue: updated.slValue,
                closePrice: updated.closePrice,
                rr: updated.rr,
            });
            console.log('▶.....Position has been successfully updated. ✔');
        });
    }
    updateUrl(url, makeOperation, when) {
        return __awaiter(this, void 0, void 0, function* () {
            if (makeOperation === 'add') {
                !this[when].includes(url) ?
                    db_1.pool.execute(`UPDATE \`positions\` SET \`${when}\` = JSON_ARRAY_APPEND(\`${when}\`, '$', :url) WHERE \`id\` = :id`, {
                        id: this.id,
                        url,
                        when,
                    })
                        .then(() => console.log('▶.....URL has been successfully updated. ✔'))
                    :
                        console.log('▶.....This URL is already addded ❌');
                return;
            }
            else if (makeOperation === 'remove') {
                this[when].includes(url) ?
                    db_1.pool.execute(`UPDATE \`positions\` SET \`${when}\` = JSON_REMOVE(\`${when}\`, JSON_UNQUOTE(JSON_SEARCH(\`${when}\`, 'one', :url))) WHERE \`id\` = :id`, {
                        id: this.id,
                        url,
                        when,
                    })
                        .then(() => console.log('▶.....URL has been successfully updated. ✔'))
                    :
                        console.log('▶.....There is no such URL ❌');
                return;
            }
        });
    }
    ;
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute("DELETE FROM `positions` WHERE `id` = :id", {
                id: this.id,
            });
            console.log('▶.....Position has been successfully deleted. ✔');
        });
    }
}
exports.PositionRecord = PositionRecord;
//# sourceMappingURL=position.record.js.map