"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRecord = void 0;
const uuid_1 = require("uuid");
const util_1 = require("util");
const bcrypt_1 = require("bcrypt");
const hashing = (0, util_1.promisify)(bcrypt_1.hash);
const db_1 = require("../utils/db");
const errors_1 = require("../utils/errors");
class UserRecord {
    constructor(obj) {
        if (!obj.email || !obj.pwd)
            throw new errors_1.ValidationError('Adres email i hasło są wymagane.');
        if (!obj.username)
            throw new errors_1.ValidationError('Nazwa użytkownika jest wymagana');
        this.id = obj.id || (0, uuid_1.v4)();
        this.username = obj.username;
        this.email = obj.email;
        this.pwd = obj.pwd;
    }
    validation() {
        return __awaiter(this, void 0, void 0, function* () {
            const userExists = yield UserRecord.getUserByUsername(this.username);
            const emailExists = yield UserRecord.getUserByEmail(this.email);
            const userIdExsts = yield UserRecord.getUserById(this.id);
            if (userExists)
                throw new errors_1.ValidationError('This username already exists');
            if (emailExists)
                throw new errors_1.ValidationError('This email already exists');
            if (userIdExsts)
                throw new errors_1.ValidationError('This user ID already exists');
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.validation();
            yield db_1.pool.execute("INSERT INTO `users` (`id`, `username`, `email`, `pwd`) VALUES(:id, :username, :email, :pwd)", {
                id: this.id,
                username: this.username,
                email: this.email,
                pwd: yield hashing(this.pwd, 10),
            });
            console.log(`▶.....User ${this.username} has been created successfully, with id ${this.id}`);
        });
    }
    static getUserById(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute("SELECT * FROM `users` WHERE `id` = :id", {
                id,
            }));
            return results.length === 0 ? null : new UserRecord(results[0]);
        });
    }
    static getUserByEmail(email) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute("SELECT * FROM `users` WHERE `email` = :email", {
                email,
            }));
            return results.length === 0 ? null : new UserRecord(results[0]);
        });
    }
    static getUserByUsername(username) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute("SELECT * FROM `users` WHERE `username` = :username", {
                username,
            }));
            return results.length === 0 ? null : new UserRecord(results[0]);
        });
    }
    update(data) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `users` SET username=:username, email=:email, pwd=:pwd WHERE id=:id", {
                id: this.id,
                username: data.username || this.username,
                email: data.email || this.email,
                pwd: data.pwd ? yield hashing(data.pwd, 10) : this.pwd,
            });
            Object.assign(this, data);
            console.log(`▶.....User ${data.username || this.username} has been successfully updated. ✔`);
            return this;
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `users` WHERE `id` = :id", {
                id: this.id,
            });
            console.log(`▶.....User ${this.username} has been successfully deleted. ✔`);
        });
    }
}
exports.UserRecord = UserRecord;
//# sourceMappingURL=user.record.js.map