"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.userRouter = void 0;
const express_1 = require("express");
const user_record_1 = require("../records/user.record");
const authLogin_1 = require("../utils/authLogin");
const errors_1 = require("../utils/errors");
const registerValidation_1 = require("../utils/registerValidation");
exports.userRouter = (0, express_1.Router)();
exports.userRouter
    .post('/login', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { email, pwd } = req.body;
    const auth = yield (0, authLogin_1.authLogin)(email, pwd);
    res.json(auth);
}))
    .post('/register', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { pwd, confirmPwd, email, username } = req.body;
    if (pwd !== confirmPwd) {
        throw new errors_1.ValidationError('Hasła muszą być takie same');
    }
    if (yield (0, registerValidation_1.isEmailTaken)(email)) {
        throw new errors_1.ValidationError('Ten adres email jest już zajęty');
    }
    if (yield (0, registerValidation_1.isUsernameTaken)(username)) {
        throw new errors_1.ValidationError('Ta nazwa użytkownika jest już zajęta');
    }
    const newUser = new user_record_1.UserRecord({ email, pwd, username });
    yield newUser.insert();
    res.json({ message: `Użytkownik ${newUser.username} został pomyślnie zarejestrowany. Możesz teraz zalogować się do swojego konta.` });
}))
    .patch('/update-username', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const user = yield user_record_1.UserRecord.getUserById(req.body.id);
    const updatedUser = yield user.update({ username: req.body.username });
    res.json({
        user: updatedUser,
        message: 'Nazwa użytkownika została zmieniona'
    });
}))
    .patch('/update-email', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const user = yield user_record_1.UserRecord.getUserById(req.body.id);
    const updatedUser = yield user.update({ email: req.body.email });
    res.json({
        user: updatedUser,
        message: `Email użytkownika został zmieniony`
    });
}))
    .patch('/update-pwd', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { pwd, confirmPwd, id } = req.body;
    if (pwd !== confirmPwd) {
        throw new errors_1.ValidationError('Podane hasła różnią się od siebie');
    }
    const user = yield user_record_1.UserRecord.getUserById(id);
    const updatedUser = yield user.update({ pwd: pwd });
    res.json({
        user: updatedUser,
        message: 'Hasło zostało zmienione'
    });
}));
//# sourceMappingURL=user.router.js.map