"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const position_record_1 = require("../records/position.record");
const db_1 = require("../utils/db");
afterAll(() => __awaiter(void 0, void 0, void 0, function* () { return yield db_1.pool.end(); }));
test('Inserted position should have an ID', () => __awaiter(void 0, void 0, void 0, function* () {
    const postiion = new position_record_1.PositionRecord({
        market: 'test/usd',
        direction: 'sell',
        date: '21-02-23',
        userId: '123testID098'
    });
    expect(postiion.id).toBeDefined();
}));
test('Market should have 0-10 sign', () => __awaiter(void 0, void 0, void 0, function* () {
    const testPos = {
        market: '',
        direction: 'sell',
        date: '21-02-23',
        userId: '123testID098'
    };
    expect(() => new position_record_1.PositionRecord(testPos)).toThrowError();
}));
test('Position should have beed updated', () => __awaiter(void 0, void 0, void 0, function* () {
    const newPosition = new position_record_1.PositionRecord({
        market: 'usd/pln',
        direction: 'buy',
        date: '21-02-23',
        userId: '123testID098'
    });
    yield newPosition.insert();
    const position = yield position_record_1.PositionRecord.getOne(newPosition.id);
    yield position.update(Object.assign(Object.assign({}, position), { descriptionBefore: 'Testowy opis', result: 'profit' }));
    const updatedPosition = yield position_record_1.PositionRecord.getOne(newPosition.id);
    expect(updatedPosition.descriptionBefore).toBeDefined();
    expect(updatedPosition.result).toBeDefined();
}));
test('Position should be deleted and throw error', () => __awaiter(void 0, void 0, void 0, function* () {
    const testPos = {
        market: 'chf/jpy',
        direction: 'sell',
        date: '21-02-23',
        userId: '123testID098'
    };
    const position = new position_record_1.PositionRecord(testPos);
    yield position.insert();
    const gettingPos = yield position_record_1.PositionRecord.getOne(position.id);
    yield gettingPos.delete();
    yield expect(position_record_1.PositionRecord.getOne(position.id)).rejects.toThrowError();
}));
test('Position should have an user ID', () => __awaiter(void 0, void 0, void 0, function* () {
    const testPos = {
        market: 'usd/pln',
        direction: 'sell',
        date: '21-02-23',
        userId: ''
    };
    expect(() => new position_record_1.PositionRecord(testPos)).toThrowError();
}));
//# sourceMappingURL=position-record.test.js.map