"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const user_record_1 = require("../records/user.record");
const db_1 = require("../utils/db");
const errors_1 = require("../utils/errors");
const bcrypt_1 = require("bcrypt");
afterAll(() => __awaiter(void 0, void 0, void 0, function* () { return yield db_1.pool.end(); }));
test('Created user should has an ID', () => __awaiter(void 0, void 0, void 0, function* () {
    const testUser = {
        username: 'tester',
        email: 'tester@example.com',
        pwd: 'password',
    };
    const user = new user_record_1.UserRecord(testUser);
    expect(user.id).toBeDefined();
}));
test('Username must be defined', () => __awaiter(void 0, void 0, void 0, function* () {
    const testUser = {
        username: '',
        email: 'asd@wp.pl',
        pwd: 'asdasd',
    };
    expect(() => new user_record_1.UserRecord(testUser)).toThrowError(errors_1.ValidationError);
}));
test('Email and Pwd must be defined', () => __awaiter(void 0, void 0, void 0, function* () {
    const testUser = {
        username: 'tester',
        email: '',
        pwd: '',
    };
    expect(() => new user_record_1.UserRecord(testUser)).toThrowError(errors_1.ValidationError);
}));
test('User password sholud be hashed', () => __awaiter(void 0, void 0, void 0, function* () {
    const testUser = {
        username: 'tester',
        email: 'tester@example.com',
        pwd: 'password',
    };
    const user = new user_record_1.UserRecord(testUser);
    yield user.insert();
    const dbUser = yield user_record_1.UserRecord.getUserById(user.id);
    expect(dbUser.pwd).not.toBe(testUser.pwd);
    expect(yield (0, bcrypt_1.compare)(testUser.pwd, dbUser.pwd)).toBe(true);
}));
test('Exisiting username should not be added to DB', () => __awaiter(void 0, void 0, void 0, function* () {
    const testUser = {
        username: 'tester',
        email: 'test@example.com',
        pwd: 'password',
    };
    const user = new user_record_1.UserRecord(testUser);
    yield expect(user.insert()).rejects.toThrowError();
}));
test('Exisiting email should not be added to DB', () => __awaiter(void 0, void 0, void 0, function* () {
    const testUser = {
        username: 'test',
        email: 'tester@example.com',
        pwd: 'password',
    };
    const user = new user_record_1.UserRecord(testUser);
    yield expect(user.insert()).rejects.toThrowError();
}));
test('User data should be updated', () => __awaiter(void 0, void 0, void 0, function* () {
    const dbuser = yield user_record_1.UserRecord.getUserByUsername('tester');
    yield dbuser.update({ username: 'tester1' });
    const updatedDbUser = yield user_record_1.UserRecord.getUserByUsername('tester1');
    expect(dbuser.id).toBe(updatedDbUser.id);
}));
test('User should be deleted', () => __awaiter(void 0, void 0, void 0, function* () {
    const user = yield user_record_1.UserRecord.getUserByUsername('tester1');
    yield user.delete();
    expect(yield user_record_1.UserRecord.getUserByUsername('tester2')).toBeNull();
}));
//# sourceMappingURL=user-record.test.js.map